==> octave2.1_2.1.35.orig.tar.gz: octave-2.1.35/scripts/control/system/sysidx.m <==
## Copyright (C) 1996, 1998 Auburn University.  All rights reserved.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by the
## Free Software Foundation; either version 2, or (at your option) any
## later version.
##
## Octave is distributed in the hope that it will be useful, but WITHOUT
## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
## for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} sysidx (@var{sys}, @var{sigtype}, @var{signamelist})
## Return indices of signals with specified signal names
## inputs given a system data structure @var{sys}, a signal type to be
## selected @var{sigtype} (@code{"in"}, @code{"out"}, @code{"st"}), and
## a list of desired signal names @var{signamelist}.
## @end deftypefn

function idxvec = sysidx (sys, sigtype, signamelist)

  if (nargin != 3)
    usage ("idxvec = sysidx (sys, sigtype, signamelist)");
  elseif (! is_struct (sys))
    error ("sys must be a system data structure");
  elseif (! isstr (sigtype))
    error ("sigtype must be a string");
  elseif (rows (sigtype) != 1)
    [nr, nc] = size (sigtype);
    error ("sigtype (%d x %d) must be a single string", nr, nc);
  endif

  ## extract correct set of signal names values
  [idxvec, msg] = listidx (list ("in", "out", "st", "yd"), sigtype);
  if (msg)
    error ("invalid sigtype = %s", sigtype);
  endif

  syssiglist = sysgetsignals (sys, sigtype);
  [idxvec, msg] = listidx (syssiglist, signamelist);
  if (length (msg))
    error ("sysidx (sigtype = %s): %s", sigtype,
	   strrep (msg, "strlist", "signamelist"));
  endif

endfunction

==> octave2.1_2.1.69.orig.tar.gz: octave-2.1.69/scripts/control/system/sysidx.m <==
## Copyright (C) 1996, 1998 Auburn University.  All rights reserved.
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by the
## Free Software Foundation; either version 2, or (at your option) any
## later version.
##
## Octave is distributed in the hope that it will be useful, but WITHOUT
## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
## for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.

## -*- texinfo -*-
## @deftypefn {Function File} {} sysidx (@var{sys}, @var{sigtype}, @var{signamelist})
## Return indices of signals with specified signal names
## inputs given a system data structure @var{sys}, a signal type to be
## selected @var{sigtype} (@code{"in"}, @code{"out"}, @code{"st"}), and
## a list of desired signal names @var{signamelist}.
## @end deftypefn

function idxvec = sysidx (sys, sigtype, signamelist)

  if (nargin != 3)
    usage ("idxvec = sysidx (sys, sigtype, signamelist)");
  elseif (! isstruct (sys))
    error ("sys must be a system data structure");
  elseif (! isstr (sigtype))
    error ("sigtype must be a string");
  elseif (rows (sigtype) != 1)
    [nr, nc] = size (sigtype);
    error ("sigtype (%d x %d) must be a single string", nr, nc);
  endif

  ## extract correct set of signal names values
  [idxvec, msg] = cellidx ({"in", "out", "st", "yd"}, sigtype);
  if (msg)
    error ("invalid sigtype = %s", sigtype);
  endif

  syssiglist = sysgetsignals (sys, sigtype);
  [idxvec, msg] = cellidx (syssiglist, signamelist);
  if (length (msg))
    error ("sysidx (sigtype = %s): %s", sigtype,
	   strrep (msg, "strlist", "signamelist"));
  endif

endfunction
